@@ -837,7 +837,7 @@ class CloudResourceService:
         policy = Box(json.loads(topic_attributes.Attributes.Policy))
         new_policy_statement = []
         for statement in policy.Statement:
-            if statement.Sid in update_statements:
+            if statement.get("Sid") and statement.Sid in update_statements:
                 new_policy_statement.append(update_statements[statement.Sid])
             else:
                 new_policy_statement.append(statement)
