@@ -57,6 +57,21 @@ class UserService:
         """
         return self.collectors[self._get_active_collector()]
 
+    @property
+    def resource_identifiers(self) -> Dict:
+        """
+        Returns a commutative mapping of resource uuid and name.
+        e.g. user_service.resource_identifiers().get("resource_name") == "resource_uuid"
+         and user_service.resource_identifiers().get("resource_uuid") == "resource_name"
+
+        Currently only supports warehouse resources.
+        """
+        resource_identifiers = {}
+        for resource in self.warehouses:
+            resource_identifiers[resource["uuid"]] = resource["name"]
+            resource_identifiers[resource["name"]] = resource["uuid"]
+        return resource_identifiers
+
     @property
     def warehouses(self) -> List[Dict]:
         """
