@@ -212,16 +212,10 @@ BI_OPTIONS = [
     )
 ]
 
-DATABRICKS_OPTIONS = [
+BASE_DATABRICKS_OPTIONS = [
     click.option(
         "--databricks-workspace-url", help="Databricks workspace URL.", required=True
     ),
-    click.option(
-        "--databricks-workspace-id", help="Databricks workspace ID.", required=True
-    ),
-    click.option(
-        "--databricks-cluster-id", help="Databricks cluster ID.", required=True
-    ),
     click.option(
         "--databricks-token",
         help=f"Databricks access token. {PASSWORD_VERBIAGE}.",
@@ -231,6 +225,23 @@ DATABRICKS_OPTIONS = [
     ),
 ]
 
+DATABRICKS_OPTIONS = [
+    *BASE_DATABRICKS_OPTIONS,
+    click.option(
+        "--databricks-workspace-id", help="Databricks workspace ID.", required=True
+    ),
+    click.option(
+        "--databricks-cluster-id", help="Databricks cluster ID.", required=True
+    ),
+]
+
+DATABRICKS_SQL_WAREHOUSE_OPTIONS = [
+    *BASE_DATABRICKS_OPTIONS,
+    click.option(
+        "--databricks-warehouse-id", help="Databricks warehouse ID.", required=True
+    ),
+]
+
 DATABRICKS_DATA_COLLECTOR_OPTIONS = [
     click.option(
         "--skip-secret-creation",
@@ -680,6 +691,23 @@ def add_databricks_delta(ctx, name, **kwargs):
     )
 
 
+@integrations.command(
+    help=f"Setup a Databricks SQL Warehouse integration. {SQL_VERBIAGE}"
+)
+@click.pass_obj
+@add_common_options(DATABRICKS_SQL_WAREHOUSE_OPTIONS)
+@add_common_options(warehouse_select_option())
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def add_databricks_sql_warehouse(ctx, name, **kwargs):
+    """
+    Onboard a databricks sql warehouse connection
+    """
+    DatabricksOnboardingService(
+        config=ctx["config"], mc_client=create_mc_client(ctx)
+    ).onboard_databricks_sql_warehouse(warehouseName=name, **kwargs)
+
+
 @integrations.command(help=f"Setup a Redshift integration. {WAREHOUSE_VERBIAGE}.")
 @click.pass_obj
 @click.option(
