@@ -11,10 +11,15 @@ from montecarlodata.common.data import OnboardingConfiguration
 from montecarlodata.integrations.onboarding.base import BaseOnboardingService
 from montecarlodata.integrations.onboarding.fields import (
     DATABRICKS_DELTA_CONNECTION_TYPE,
+    DATABRICKS_SQL_WAREHOUSE_CONNECTION_TYPE,
     DATA_LAKE_WAREHOUSE_TYPE,
     EXPECTED_DATABRICKS_GQL_RESPONSE_FIELD,
+    EXPECTED_DATABRICKS_SQL_WAREHOUSE_GQL_RESPONSE_FIELD,
+)
+from montecarlodata.queries.onboarding import (
+    TEST_DATABRICKS_CRED_MUTATION,
+    DatabricksSqlWarehouseOnboardingQueries,
 )
-from montecarlodata.queries.onboarding import TEST_DATABRICKS_CRED_MUTATION
 
 DEFAULT_GATEWAY_URL = os.getenv(
     "MC_INTEGRATION_GATEWAY_URL",
@@ -159,3 +164,13 @@ class DatabricksOnboardingService(BaseOnboardingService):
         query.get_current_databricks_notebook_version()
         resp = self._mc_client(query)
         click.echo(resp.get_current_databricks_notebook_version)
+
+    @manage_errors
+    def onboard_databricks_sql_warehouse(self, **kwargs):
+        # Onboard
+        self.onboard(
+            validation_query=DatabricksSqlWarehouseOnboardingQueries.test_credentials.query,
+            validation_response=EXPECTED_DATABRICKS_SQL_WAREHOUSE_GQL_RESPONSE_FIELD,
+            connection_type=DATABRICKS_SQL_WAREHOUSE_CONNECTION_TYPE,
+            **kwargs
+        )
