@@ -14,7 +14,7 @@ class Queries:
             }
         }
         """,
-        operation='createIntegrationKey'
+        operation="createIntegrationKey",
     )
 
     delete = GQL(
@@ -25,7 +25,7 @@ class Queries:
             }
         }
         """,
-        operation='deleteIntegrationKey'
+        operation="deleteIntegrationKey",
     )
 
     get_all = GQL(
@@ -45,5 +45,5 @@ class Queries:
             }
         }
         """,
-        operation='getIntegrationKeys'
+        operation="getIntegrationKeys",
     )
