@@ -17,7 +17,7 @@ query getUser {
           type
           createdOn
           jobTypes
-          connectionIdentifier {
+          connectionIdentifiers {
             key
             value
           }
@@ -29,12 +29,13 @@ query getUser {
       }
       bi {
         uuid
+        name
         connections {
           uuid
           type
           createdOn
           jobTypes
-          connectionIdentifier {
+          connectionIdentifiers {
             key
             value
           }
