@@ -22,10 +22,14 @@ class DbtImportServiceTests(TestCase):
         self.mock_config = Mock()
         self.mock_mc_client = Mock()
         self.mock_user_service = Mock()
+        self.mock_pii_service = Mock()
+        self.mock_pii_service.get_pii_filters_config.return_value = None
+
         self.service = DbtImportService(
             config=self.mock_config,
             mc_client=self.mock_mc_client,
             user_service=self.mock_user_service,
+            pii_service=self.mock_pii_service,
         )
 
     @patch.object(DbtImporter, "import_run")
