@@ -689,6 +689,19 @@ class CloudResourcesTest(TestCase):
             '{"Statement": [{"Sid": "foo", "bar": "baz"}, {"x": "y"}]}',
         )
 
+    def test_extend_topic_policy_topic_attributes_without_sid(self):
+        topic_attributes = Box(
+            {"Attributes": {"Policy": '{"Statement": [{"foo": "bar"}]}'}}
+        )
+        new_statements = [{"x": "y"}]
+        update_statements = {"foo": {"Sid": "foo", "bar": "baz"}}
+        self.assertEqual(
+            '{"Statement": [{"foo": "bar"}, {"x": "y"}]}',
+            self._service._extend_topic_policy(
+                topic_attributes, new_statements, update_statements
+            ),
+        )
+
     @patch("montecarlodata.common.resources.prompt_connection")
     @patch.object(CloudResourceService, "_save_event_properties")
     def test_update_event_q(self, mock_save_event_properties, mock_prompt):
